# elk_distributions
Probability Distributions Package

### Table of Contents

1. [Installation](#installation)
2. [Project Description](#Project)
3. [File Description](#files)
5. [Licensing, Authors, and Acknowledgements](#licensing)

## Installation <a name="installation"></a>

- Requirements
  - Python 3.X
  - matplotlib

## Project Description<a name="Project"></a>

This project is a fairly simple package that provides some quick
methods for initializing and plotting common probability distributions.

## File Descriptions <a name="files"></a>
- /elkdist/
  - general_distributions.py: Module containing the parent class with some common functionality between all distributions
  - gaussian_distribution.py : Module containing implementation class for a Gaussian/Normal distribution
  - binomial_distribution.py :  Module containing implementation class for a Binomial distribution
- /elkdist/tests/
  - numbers.txt: Test file for testing the Gaussian distribution class and its methods
  - numbers_binomial.txt: Test file for testing the Bionomial distribution class and its methods
  - tests.py: Unit tests for testing all classes and their methods.


## Licensing, Authors, Acknowledgements<a name="licensing"></a>
Credit to the Udacity lectures for some of the coding and visualization ideas.
